[Spice-commits] client/gui client/inputs_channel.cpp client/inputs_channel.h client/red_channel.cpp client/red_channel.h client/red_peer.cpp client/red_peer.h client/tunnel_channel.cpp common/canvas_base.c common/canvas_base.h common/draw.h common/gdi_canvas.c common/gl_canvas.c common/messages.h server/Makefile.am server/red_channel.c server/red_channel.h server/red_parse_qxl.c server/red_parse_qxl.h server/reds.c server/red_worker.c spice1.proto spice.proto

Alexander Larsson alexl at kemper.freedesktop.org
Thu Jul 8 09:28:42 PDT 2010


 client/gui/resource_provider.cpp |    2 
 client/inputs_channel.cpp        |    8 +--
 client/inputs_channel.h          |    2 
 client/red_channel.cpp           |   32 +++++++-------
 client/red_channel.h             |   12 ++---
 client/red_peer.cpp              |    8 +--
 client/red_peer.h                |   12 ++---
 client/tunnel_channel.cpp        |    8 +--
 common/canvas_base.c             |    2 
 common/canvas_base.h             |    2 
 common/draw.h                    |    4 -
 common/gdi_canvas.c              |    2 
 common/gl_canvas.c               |    2 
 common/messages.h                |    2 
 server/Makefile.am               |    2 
 server/red_channel.c             |    2 
 server/red_channel.h             |    4 -
 server/red_parse_qxl.c           |    6 +-
 server/red_parse_qxl.h           |    2 
 server/red_worker.c              |   84 +++++++++++++++++++--------------------
 server/reds.c                    |   20 ++++-----
 spice.proto                      |    2 
 spice1.proto                     |    2 
 23 files changed, 111 insertions(+), 111 deletions(-)

New commits:
commit 1a6e77d6d4da9c73dc706574ea3e3fbaa8142f29
Author: Alexander Larsson <alexl at redhat.com>
Date:   Thu Jul 8 18:26:37 2010 +0200

    Fix various misspellings
    
    letancy -> latency
    compund -> compound
    SpicedSubMessage -> SpiceSubMessage
    modifaiers -> modifiers
    massage -> message
    outgoiong -> outgoing
    AlphaBlnd -> AlphaBlend
    remoth -> remote
    modifires -> modifiers
    secore -> secure

diff --git a/client/gui/resource_provider.cpp b/client/gui/resource_provider.cpp
index 47f86a4..52e3381 100644
--- a/client/gui/resource_provider.cpp
+++ b/client/gui/resource_provider.cpp
@@ -108,7 +108,7 @@ struct ResString{
     {STR_BUTTON_BACK, "Back"},
     {STR_LABEL_HOST, "Host"},
     {STR_LABEL_PORT, "Port"},
-    {STR_LABEL_SPORT, "Secore port"},
+    {STR_LABEL_SPORT, "Secure port"},
     {STR_LABEL_PASSWORD, "Password"},
     {0, NULL},
 };
diff --git a/client/inputs_channel.cpp b/client/inputs_channel.cpp
index 09fc9e1..9ff5479 100644
--- a/client/inputs_channel.cpp
+++ b/client/inputs_channel.cpp
@@ -23,7 +23,7 @@
 #include "application.h"
 #include "display_channel.h"
 
-#define SYNC_REMOTH_MODIFIRES
+#define SYNC_REMOTE_MODIFIERS
 
 class SetInputsHandlerEvent: public Event {
 public:
@@ -187,7 +187,7 @@ InputsChannel::InputsChannel(RedClient& client, uint32_t id)
     handler->set_handler(SPICE_MSG_NOTIFY, &InputsChannel::handle_notify);
 
     handler->set_handler(SPICE_MSG_INPUTS_INIT, &InputsChannel::handle_init);
-    handler->set_handler(SPICE_MSG_INPUTS_KEY_MODIFIERS, &InputsChannel::handle_modifaiers);
+    handler->set_handler(SPICE_MSG_INPUTS_KEY_MODIFIERS, &InputsChannel::handle_modifiers);
     handler->set_handler(SPICE_MSG_INPUTS_MOUSE_MOTION_ACK, &InputsChannel::handle_motion_ack);
 }
 
@@ -217,7 +217,7 @@ void InputsChannel::handle_init(RedPeer::InMessage* message)
     get_client().push_event(*set_handler_event);
 }
 
-void InputsChannel::handle_modifaiers(RedPeer::InMessage* message)
+void InputsChannel::handle_modifiers(RedPeer::InMessage* message)
 {
     SpiceMsgInputsKeyModifiers* init = (SpiceMsgInputsKeyModifiers*)message->data();
     _modifiers = init->modifiers;
@@ -404,7 +404,7 @@ void InputsChannel::set_local_modifiers()
 
 void InputsChannel::on_focus_in()
 {
-#ifdef SYNC_REMOTH_MODIFIRES
+#ifdef SYNC_REMOTE_MODIFIERS
     Message* message = new Message(SPICE_MSGC_INPUTS_KEY_MODIFIERS);
     SpiceMsgcKeyModifiers modifiers;
     modifiers.modifiers = Platform::get_keyboard_lock_modifiers();
diff --git a/client/inputs_channel.h b/client/inputs_channel.h
index 9a0e8ff..00e185c 100644
--- a/client/inputs_channel.h
+++ b/client/inputs_channel.h
@@ -50,7 +50,7 @@ private:
     void set_local_modifiers();
 
     void handle_init(RedPeer::InMessage* message);
-    void handle_modifaiers(RedPeer::InMessage* message);
+    void handle_modifiers(RedPeer::InMessage* message);
     void handle_motion_ack(RedPeer::InMessage* message);
 
     static uint32_t get_make_scan_code(RedKey key);
diff --git a/client/red_channel.cpp b/client/red_channel.cpp
index 3fa3f51..b475927 100644
--- a/client/red_channel.cpp
+++ b/client/red_channel.cpp
@@ -336,9 +336,9 @@ void RedChannel::post_message(RedChannel::OutMessage* message)
     _send_trigger.trigger();
 }
 
-RedPeer::CompundInMessage *RedChannel::recive()
+RedPeer::CompoundInMessage *RedChannel::recive()
 {
-    CompundInMessage *message = RedChannelBase::recive();
+    CompoundInMessage *message = RedChannelBase::recive();
     on_message_recived();
     return message;
 }
@@ -589,12 +589,12 @@ void RedChannel::recive_messages()
             _incomming_header_pos = n;
             return;
         }
-        AutoRef<CompundInMessage> message(new CompundInMessage(_incomming_header.serial,
-                                                               _incomming_header.type,
-                                                               _incomming_header.size,
-                                                               _incomming_header.sub_list));
-        n = RedPeer::recive((*message)->data(), (*message)->compund_size());
-        if (n != (*message)->compund_size()) {
+        AutoRef<CompoundInMessage> message(new CompoundInMessage(_incomming_header.serial,
+                                                                 _incomming_header.type,
+                                                                 _incomming_header.size,
+                                                                 _incomming_header.sub_list));
+        n = RedPeer::recive((*message)->data(), (*message)->compound_size());
+        if (n != (*message)->compound_size()) {
             _incomming_message = message.release();
             _incomming_message_pos = n;
             return;
@@ -626,22 +626,22 @@ void RedChannel::on_event()
             return;
         }
         _incomming_header_pos = 0;
-        _incomming_message = new CompundInMessage(_incomming_header.serial,
-                                                  _incomming_header.type,
-                                                  _incomming_header.size,
-                                                  _incomming_header.sub_list);
+        _incomming_message = new CompoundInMessage(_incomming_header.serial,
+                                                   _incomming_header.type,
+                                                   _incomming_header.size,
+                                                   _incomming_header.sub_list);
         _incomming_message_pos = 0;
     }
 
     if (_incomming_message) {
         _incomming_message_pos += RedPeer::recive(_incomming_message->data() +
                                                   _incomming_message_pos,
-                                                  _incomming_message->compund_size() -
+                                                  _incomming_message->compound_size() -
                                                   _incomming_message_pos);
-        if (_incomming_message_pos != _incomming_message->compund_size()) {
+        if (_incomming_message_pos != _incomming_message->compound_size()) {
             return;
         }
-        AutoRef<CompundInMessage> message(_incomming_message);
+        AutoRef<CompoundInMessage> message(_incomming_message);
         _incomming_message = NULL;
         on_message_recived();
         _message_handler->handle_message(*(*message));
@@ -680,7 +680,7 @@ void RedChannel::handle_migrate(RedPeer::InMessage* message)
     if (migrate->flags & SPICE_MIGRATE_NEED_FLUSH) {
         send_migrate_flush_mark();
     }
-    AutoRef<CompundInMessage> data_message;
+    AutoRef<CompoundInMessage> data_message;
     if (migrate->flags & SPICE_MIGRATE_NEED_DATA_TRANSFER) {
         data_message.reset(recive());
     }
diff --git a/client/red_channel.h b/client/red_channel.h
index fd01f20..a326680 100644
--- a/client/red_channel.h
+++ b/client/red_channel.h
@@ -126,7 +126,7 @@ public:
     virtual void disconnect();
     virtual bool abort();
 
-    virtual CompundInMessage *recive();
+    virtual CompoundInMessage *recive();
 
     virtual void post_message(RedChannel::OutMessage* message);
     int get_connection_error() { return _error;}
@@ -189,7 +189,7 @@ private:
 
     SpiceDataHeader _incomming_header;
     uint32_t _incomming_header_pos;
-    RedPeer::CompundInMessage* _incomming_message;
+    RedPeer::CompoundInMessage* _incomming_message;
     uint32_t _incomming_message_pos;
 
     uint32_t _message_ack_count;
@@ -232,7 +232,7 @@ class RedChannel::MessageHandler {
 public:
     MessageHandler() {}
     virtual ~MessageHandler() {}
-    virtual void handle_message(RedPeer::CompundInMessage& message) = 0;
+    virtual void handle_message(RedPeer::CompoundInMessage& message) = 0;
 };
 
 
@@ -241,7 +241,7 @@ class MessageHandlerImp: public RedChannel::MessageHandler {
 public:
     MessageHandlerImp(HandlerClass& obj);
     ~MessageHandlerImp() { delete [] _handlers; };
-    virtual void handle_message(RedPeer::CompundInMessage& message);
+    virtual void handle_message(RedPeer::CompoundInMessage& message);
     typedef void (HandlerClass::*Handler)(RedPeer::InMessage* message);
     void set_handler(unsigned int id, Handler handler);
 
@@ -264,7 +264,7 @@ MessageHandlerImp<HandlerClass, channel_id>::MessageHandlerImp(HandlerClass& obj
 }
 
 template <class HandlerClass, unsigned int channel_id>
-void MessageHandlerImp<HandlerClass, channel_id>::handle_message(RedPeer::CompundInMessage&
+void MessageHandlerImp<HandlerClass, channel_id>::handle_message(RedPeer::CompoundInMessage&
                                                                  message)
 {
     uint8_t *msg;
@@ -288,7 +288,7 @@ void MessageHandlerImp<HandlerClass, channel_id>::handle_message(RedPeer::Compun
         SpiceSubMessageList *sub_list;
         sub_list = (SpiceSubMessageList *)(message.data() + message.sub_list());
         for (int i = 0; i < sub_list->size; i++) {
-            SpicedSubMessage *sub = (SpicedSubMessage *)(message.data() + sub_list->sub_messages[i]);
+            SpiceSubMessage *sub = (SpiceSubMessage *)(message.data() + sub_list->sub_messages[i]);
             msg = (uint8_t *)(sub + 1);
             type = sub->type;
             size = sub->size;
diff --git a/client/red_peer.cpp b/client/red_peer.cpp
index 2d9f5b9..88fc9ad 100644
--- a/client/red_peer.cpp
+++ b/client/red_peer.cpp
@@ -661,14 +661,14 @@ uint32_t RedPeer::recive(uint8_t *buf, uint32_t size)
     return pos - buf;
 }
 
-RedPeer::CompundInMessage* RedPeer::recive()
+RedPeer::CompoundInMessage* RedPeer::recive()
 {
     SpiceDataHeader header;
-    AutoRef<CompundInMessage> message;
+    AutoRef<CompoundInMessage> message;
 
     recive((uint8_t*)&header, sizeof(SpiceDataHeader));
-    message.reset(new CompundInMessage(header.serial, header.type, header.size, header.sub_list));
-    recive((*message)->data(), (*message)->compund_size());
+    message.reset(new CompoundInMessage(header.serial, header.type, header.size, header.sub_list));
+    recive((*message)->data(), (*message)->compound_size());
     return message.release();
 }
 
diff --git a/client/red_peer.h b/client/red_peer.h
index 25a3560..a4310e6 100644
--- a/client/red_peer.h
+++ b/client/red_peer.h
@@ -34,7 +34,7 @@ public:
     virtual ~RedPeer();
 
     class InMessage;
-    class CompundInMessage;
+    class CompoundInMessage;
     class OutMessage;
     class DisconnectedException {};
 
@@ -114,7 +114,7 @@ public:
     void close();
     void enable() { _shut = false;}
 
-    virtual CompundInMessage* recive();
+    virtual CompoundInMessage* recive();
     uint32_t do_send(OutMessage& message, uint32_t skip_bytes);
     uint32_t send(OutMessage& message);
 
@@ -169,9 +169,9 @@ protected:
     uint8_t* _data;
 };
 
-class RedPeer::CompundInMessage: public RedPeer::InMessage {
+class RedPeer::CompoundInMessage: public RedPeer::InMessage {
 public:
-    CompundInMessage(uint64_t _serial, uint16_t type, uint32_t size, uint32_t sub_list)
+    CompoundInMessage(uint64_t _serial, uint16_t type, uint32_t size, uint32_t sub_list)
         : InMessage(type, size, new uint8_t[size])
         , _refs (1)
         , _serial (_serial)
@@ -186,10 +186,10 @@ public:
     uint32_t sub_list() { return _sub_list;}
 
     virtual uint32_t size() { return _sub_list ? _sub_list : _size;}
-    uint32_t compund_size() {return _size;}
+    uint32_t compound_size() {return _size;}
 
 protected:
-    virtual ~CompundInMessage() { delete[] _data;}
+    virtual ~CompoundInMessage() { delete[] _data;}
 
 private:
     int _refs;
diff --git a/client/tunnel_channel.cpp b/client/tunnel_channel.cpp
index 0b55aff..7047d46 100644
--- a/client/tunnel_channel.cpp
+++ b/client/tunnel_channel.cpp
@@ -33,7 +33,7 @@ class OutSocketMessage;
 
 class InSocketMessage: public ClientNetSocket::SendBuffer {
 public:
-    InSocketMessage(RedChannel::CompundInMessage& full_msg);
+    InSocketMessage(RedChannel::CompoundInMessage& full_msg);
 
     const uint8_t* data();
     uint32_t size();
@@ -45,12 +45,12 @@ protected:
 
 private:
     int _refs;
-    RedChannel::CompundInMessage& _full_msg;
+    RedChannel::CompoundInMessage& _full_msg;
     SpiceMsgTunnelSocketData* _sckt_msg;
     uint32_t _buf_size;
 };
 
-InSocketMessage::InSocketMessage(RedChannel::CompundInMessage& full_msg)
+InSocketMessage::InSocketMessage(RedChannel::CompoundInMessage& full_msg)
     : _refs (1)
     , _full_msg (full_msg)
 {
@@ -450,7 +450,7 @@ void TunnelChannel::handle_socket_data(RedPeer::InMessage* message)
     }
 
     InSocketMessage* sckt_msg = new InSocketMessage(*(
-                                          static_cast<RedChannel::CompundInMessage*>(message)));
+                                          static_cast<RedChannel::CompoundInMessage*>(message)));
     if (sckt_msg->size() > _max_socket_data_size) {
         THROW("%s: socket data exceeds size limit %d > %d connection_id=%d", __FUNCTION__,
               sckt_msg->size(), _max_socket_data_size, sckt->id());
diff --git a/common/canvas_base.c b/common/canvas_base.c
index ef60d21..52796ed 100644
--- a/common/canvas_base.c
+++ b/common/canvas_base.c
@@ -2322,7 +2322,7 @@ static void canvas_draw_transparent(SpiceCanvas *spice_canvas, SpiceRect *bbox,
     pixman_region32_fini(&dest_region);
 }
 
-static void canvas_draw_alpha_blend(SpiceCanvas *spice_canvas, SpiceRect *bbox, SpiceClip *clip, SpiceAlphaBlnd* alpha_blend)
+static void canvas_draw_alpha_blend(SpiceCanvas *spice_canvas, SpiceRect *bbox, SpiceClip *clip, SpiceAlphaBlend* alpha_blend)
 {
     CanvasBase *canvas = (CanvasBase *)spice_canvas;
     pixman_region32_t dest_region;
diff --git a/common/canvas_base.h b/common/canvas_base.h
index 0d25a3f..2166dcf 100644
--- a/common/canvas_base.h
+++ b/common/canvas_base.h
@@ -132,7 +132,7 @@ typedef struct {
     void (*draw_whiteness)(SpiceCanvas *canvas, SpiceRect *bbox, SpiceClip *clip, SpiceWhiteness *whiteness);
     void (*draw_invers)(SpiceCanvas *canvas, SpiceRect *bbox, SpiceClip *clip, SpiceInvers *invers);
     void (*draw_transparent)(SpiceCanvas *canvas, SpiceRect *bbox, SpiceClip *clip, SpiceTransparent* transparent);
-    void (*draw_alpha_blend)(SpiceCanvas *canvas, SpiceRect *bbox, SpiceClip *clip, SpiceAlphaBlnd* alpha_blend);
+    void (*draw_alpha_blend)(SpiceCanvas *canvas, SpiceRect *bbox, SpiceClip *clip, SpiceAlphaBlend* alpha_blend);
     void (*put_image)(SpiceCanvas *canvas,
 #ifdef WIN32
                       HDC dc,
diff --git a/common/draw.h b/common/draw.h
index ab9da69..95f07b8 100644
--- a/common/draw.h
+++ b/common/draw.h
@@ -205,12 +205,12 @@ typedef struct SpiceTransparent {
     uint32_t true_color;
 } SpiceTransparent;
 
-typedef struct SpiceAlphaBlnd {
+typedef struct SpiceAlphaBlend {
     uint16_t alpha_flags;
     uint8_t alpha;
     SpiceImage *src_bitmap;
     SpiceRect src_area;
-} SpiceAlphaBlnd;
+} SpiceAlphaBlend;
 
 typedef struct SpiceRop3 {
     SpiceImage *src_bitmap;
diff --git a/common/gdi_canvas.c b/common/gdi_canvas.c
index 845ddd5..eda1529 100644
--- a/common/gdi_canvas.c
+++ b/common/gdi_canvas.c
@@ -1251,7 +1251,7 @@ static void gdi_draw_image_alpha(HDC dest_dc, const SpiceRect *src, const SpiceR
     release_bitmap(dc, bitmap, prev_bitmap, 0);
 }
 
-static void gdi_canvas_draw_alpha_blend(SpiceCanvas *spice_canvas, SpiceRect *bbox, SpiceClip *clip, SpiceAlphaBlnd* alpha_blend)
+static void gdi_canvas_draw_alpha_blend(SpiceCanvas *spice_canvas, SpiceRect *bbox, SpiceClip *clip, SpiceAlphaBlend* alpha_blend)
 {
     GdiCanvas *canvas = (GdiCanvas *)spice_canvas;
     GdiCanvas *gdi_surface;
diff --git a/common/gl_canvas.c b/common/gl_canvas.c
index a5c8511..3edb2c7 100644
--- a/common/gl_canvas.c
+++ b/common/gl_canvas.c
@@ -400,7 +400,7 @@ static void gl_canvas_draw_opaque(SpiceCanvas *spice_canvas, SpiceRect *bbox, Sp
     glc_flush(canvas->glc);
 }
 
-static void gl_canvas_draw_alpha_blend(SpiceCanvas *spice_canvas, SpiceRect *bbox, SpiceClip *clip, SpiceAlphaBlnd *alpha_blend)
+static void gl_canvas_draw_alpha_blend(SpiceCanvas *spice_canvas, SpiceRect *bbox, SpiceClip *clip, SpiceAlphaBlend *alpha_blend)
 {
     GLCanvas *canvas = (GLCanvas *)spice_canvas;
     pixman_image_t *surface;
diff --git a/common/messages.h b/common/messages.h
index a6433b0..65541c5 100644
--- a/common/messages.h
+++ b/common/messages.h
@@ -226,7 +226,7 @@ typedef struct SpiceMsgDisplayDrawTransparent {
 
 typedef struct SpiceMsgDisplayDrawAlphaBlend {
     SpiceMsgDisplayBase base;
-    SpiceAlphaBlnd data;
+    SpiceAlphaBlend data;
 } SpiceMsgDisplayDrawAlphaBlend;
 
 typedef struct SpiceMsgDisplayCopyBits {
diff --git a/server/Makefile.am b/server/Makefile.am
index d82f4cf..a12009c 100644
--- a/server/Makefile.am
+++ b/server/Makefile.am
@@ -22,7 +22,7 @@ spice_built_sources = generated_marshallers.c generated_marshallers.h generated_
 generated_demarshallers.c: $(top_srcdir)/spice.proto
 	$(PYTHON) $(top_srcdir)/spice_codegen.py --generate-demarshallers --server --include red_common.h $(top_srcdir)/spice.proto generated_demarshallers.c
 
-STRUCTS=-M String -M Rect -M Point -M DisplayBase -M Fill -M Opaque -M Copy -M Blend -M Blackness -M Whiteness -M Invers -M Rop3 -M Stroke -M Text -M Transparent -M AlphaBlnd
+STRUCTS=-M String -M Rect -M Point -M DisplayBase -M Fill -M Opaque -M Copy -M Blend -M Blackness -M Whiteness -M Invers -M Rop3 -M Stroke -M Text -M Transparent -M AlphaBlend
 generated_marshallers.c: $(top_srcdir)/spice.proto
 	$(PYTHON) $(top_srcdir)/spice_codegen.py --include red_common.h --generate-marshallers $(STRUCTS) --server $(top_srcdir)/spice.proto generated_marshallers.c
 
diff --git a/server/red_channel.c b/server/red_channel.c
index 9f02822..f547f5a 100644
--- a/server/red_channel.c
+++ b/server/red_channel.c
@@ -406,7 +406,7 @@ static void red_channel_send(RedChannel *channel)
     red_peer_handle_outgoing(channel->peer, &channel->outgoing);
 }
 
-void red_channel_begin_send_massage(RedChannel *channel)
+void red_channel_begin_send_message(RedChannel *channel)
 {
     channel->send_data.size = channel->send_data.header.size + sizeof(SpiceDataHeader);
     channel->ack_data.messages_window++;
diff --git a/server/red_parse_qxl.c b/server/red_parse_qxl.c
index 09f6b90..127141c 100644
--- a/server/red_parse_qxl.c
+++ b/server/red_parse_qxl.c
@@ -515,7 +515,7 @@ static void red_put_transparent(SpiceTransparent *red)
 }
 
 static void red_get_alpha_blend_ptr(RedMemSlotInfo *slots, int group_id,
-                                    SpiceAlphaBlnd *red, QXLAlphaBlnd *qxl)
+                                    SpiceAlphaBlend *red, QXLAlphaBlend *qxl)
 {
     red->alpha_flags = qxl->alpha_flags;
     red->alpha       = qxl->alpha;
@@ -524,14 +524,14 @@ static void red_get_alpha_blend_ptr(RedMemSlotInfo *slots, int group_id,
 }
 
 static void red_get_alpha_blend_ptr_compat(RedMemSlotInfo *slots, int group_id,
-                                           SpiceAlphaBlnd *red, QXLCompatAlphaBlnd *qxl)
+                                           SpiceAlphaBlend *red, QXLCompatAlphaBlend *qxl)
 {
     red->alpha       = qxl->alpha;
     red->src_bitmap  = red_get_image(slots, group_id, qxl->src_bitmap);
     red_get_rect_ptr(&red->src_area, &qxl->src_area);
 }
 
-static void red_put_alpha_blend(SpiceAlphaBlnd *red)
+static void red_put_alpha_blend(SpiceAlphaBlend *red)
 {
     red_put_image(red->src_bitmap);
 }
diff --git a/server/red_parse_qxl.h b/server/red_parse_qxl.h
index 0d713e8..e80da8a 100644
--- a/server/red_parse_qxl.h
+++ b/server/red_parse_qxl.h
@@ -40,7 +40,7 @@ typedef struct RedDrawable {
         SpiceOpaque opaque;
         SpiceCopy copy;
         SpiceTransparent transparent;
-        SpiceAlphaBlnd alpha_blend;
+        SpiceAlphaBlend alpha_blend;
         struct {
             SpicePoint src_pos;
         } copy_bits;
diff --git a/server/red_worker.c b/server/red_worker.c
index dfd445a..786387f 100644
--- a/server/red_worker.c
+++ b/server/red_worker.c
@@ -992,8 +992,8 @@ static inline void red_detach_stream(RedWorker *worker, Stream *stream);
 #endif
 static void red_stop_stream(RedWorker *worker, Stream *stream);
 static inline void red_stream_maintenance(RedWorker *worker, Drawable *candidate, Drawable *sect);
-static inline void red_begin_send_massage(RedChannel *channel, void *item);
-static inline void display_begin_send_massage(DisplayChannel *channel, void *item);
+static inline void red_begin_send_message(RedChannel *channel, void *item);
+static inline void display_begin_send_message(DisplayChannel *channel, void *item);
 static void red_receive(RedChannel *channel);
 static void red_release_pixmap_cache(DisplayChannel *channel);
 static void red_release_glz(DisplayChannel *channel);
@@ -4145,7 +4145,7 @@ static void red_draw_qxl_drawable(RedWorker *worker, Drawable *drawable)
         break;
     }
     case QXL_DRAW_ALPHA_BLEND: {
-        SpiceAlphaBlnd alpha_blend = drawable->red_drawable->u.alpha_blend;
+        SpiceAlphaBlend alpha_blend = drawable->red_drawable->u.alpha_blend;
         SpiceImage img1;
         localize_bitmap(worker, &alpha_blend.src_bitmap, &img1);
         canvas->ops->draw_alpha_blend(canvas,
@@ -7098,15 +7098,15 @@ static FillBitsType red_send_qxl_draw_alpha_blend(RedWorker *worker,
     RedChannel *channel = &display_channel->base;
     RedDrawable *drawable = item->red_drawable;
     SpiceMarshaller *src_bitmap_out;
-    SpiceAlphaBlnd alpha_blend;
+    SpiceAlphaBlend alpha_blend;
     FillBitsType src_send_type;
 
     fill_base(display_channel, item);
     channel->send_data.header->type = SPICE_MSG_DISPLAY_DRAW_ALPHA_BLEND;
     alpha_blend = drawable->u.alpha_blend;
-    spice_marshall_AlphaBlnd(channel->send_data.marshaller,
-                             &alpha_blend,
-                             &src_bitmap_out);
+    spice_marshall_AlphaBlend(channel->send_data.marshaller,
+                              &alpha_blend,
+                              &src_bitmap_out);
     src_send_type = fill_bits(display_channel, src_bitmap_out, alpha_blend.src_bitmap, item, src_allowed_lossy);
 
     return src_send_type;
@@ -7636,7 +7636,7 @@ static void red_lossy_send_qxl_drawable(RedWorker *worker, DisplayChannel *displ
 
     // a message is pending
     if (display_channel->base.send_data.header->type != 0) {
-        display_begin_send_massage(display_channel, &item->pipe_item);
+        display_begin_send_message(display_channel, &item->pipe_item);
     }
 }
 
@@ -7688,7 +7688,7 @@ static inline void red_send_qxl_drawable(RedWorker *worker, DisplayChannel *disp
     default:
         red_error("invalid type");
     }
-    display_begin_send_massage(display_channel, &item->pipe_item);
+    display_begin_send_message(display_channel, &item->pipe_item);
 }
 
 #define MAX_SEND_VEC 100
@@ -7770,7 +7770,7 @@ static void display_channel_push_release(DisplayChannel *channel, uint8_t type,
     free_list->res->resources[free_list->res->count++].id = id;
 }
 
-static inline void red_begin_send_massage(RedChannel *channel, void *item)
+static inline void red_begin_send_message(RedChannel *channel, void *item)
 {
     spice_marshaller_flush(channel->send_data.marshaller);
     channel->send_data.size = spice_marshaller_get_total_size(channel->send_data.marshaller);
@@ -7780,7 +7780,7 @@ static inline void red_begin_send_massage(RedChannel *channel, void *item)
     red_send_data(channel, item);
 }
 
-static inline void display_begin_send_massage(DisplayChannel *channel, void *item)
+static inline void display_begin_send_message(DisplayChannel *channel, void *item)
 {
     FreeList *free_list = &channel->send_data.free_list;
 
@@ -7827,7 +7827,7 @@ static inline void display_begin_send_massage(DisplayChannel *channel, void *ite
         spice_marshaller_add_uint32(sub_list_m, spice_marshaller_get_offset(inval_m));
         channel->base.send_data.header->sub_list = spice_marshaller_get_offset(sub_list_m);
     }
-    red_begin_send_massage((RedChannel *)channel, item);
+    red_begin_send_message((RedChannel *)channel, item);
 }
 
 static inline RedChannel *red_ref_channel(RedChannel *channel)
@@ -8105,7 +8105,7 @@ static inline int red_send_stream_data(DisplayChannel *display_channel, Drawable
     spice_marshaller_add_ref(channel->send_data.marshaller,
                              display_channel->send_data.stream_outbuf, n + PADDING);
 
-    display_begin_send_massage(display_channel, NULL);
+    display_begin_send_message(display_channel, NULL);
     agent->lats_send_time = time_now;
     return TRUE;
 }
@@ -8138,21 +8138,21 @@ static void red_send_set_ack(RedChannel *channel)
 
     spice_marshall_msg_set_ack(channel->send_data.marshaller, &ack);
 
-    red_begin_send_massage(channel, NULL);
+    red_begin_send_message(channel, NULL);
 }
 
 static inline void red_send_verb(RedChannel *channel, uint16_t verb)
 {
     ASSERT(channel);
     channel->send_data.header->type = verb;
-    red_begin_send_massage(channel, NULL);
+    red_begin_send_message(channel, NULL);
 }
 
 static inline void display_send_verb(DisplayChannel *channel, uint16_t verb)
 {
     ASSERT(channel);
     channel->base.send_data.header->type = verb;
-    display_begin_send_massage(channel, NULL);
+    display_begin_send_message(channel, NULL);
 }
 
 static inline void __red_send_inval(RedChannel *channel, CacheItem *cach_item)
@@ -8168,13 +8168,13 @@ static inline void __red_send_inval(RedChannel *channel, CacheItem *cach_item)
 static void red_send_inval(RedChannel *channel, CacheItem *cach_item)
 {
     __red_send_inval(channel, cach_item);
-    red_begin_send_massage(channel, NULL);
+    red_begin_send_message(channel, NULL);
 }
 
 static void red_display_send_inval(DisplayChannel *display_channel, CacheItem *cach_item)
 {
     __red_send_inval((RedChannel *)display_channel, cach_item);
-    display_begin_send_massage(display_channel, NULL);
+    display_begin_send_message(display_channel, NULL);
 }
 
 static void display_channel_send_migrate(DisplayChannel *display_channel)
@@ -8185,7 +8185,7 @@ static void display_channel_send_migrate(DisplayChannel *display_channel)
     migrate.flags = SPICE_MIGRATE_NEED_FLUSH | SPICE_MIGRATE_NEED_DATA_TRANSFER;
     spice_marshall_msg_migrate(display_channel->base.send_data.marshaller, &migrate);
     display_channel->expect_migrate_mark = TRUE;
-    display_begin_send_massage(display_channel, NULL);
+    display_begin_send_message(display_channel, NULL);
 }
 
 static void display_channel_send_migrate_data(DisplayChannel *display_channel)
@@ -8216,7 +8216,7 @@ static void display_channel_send_migrate_data(DisplayChannel *display_channel)
 
     spice_marshaller_add_ref(display_channel->base.send_data.marshaller,
                              (uint8_t *)&display_data, sizeof(display_data));
-    display_begin_send_massage(display_channel, NULL);
+    display_begin_send_message(display_channel, NULL);
 }
 
 static void display_channel_pixmap_sync(DisplayChannel *display_channel)
@@ -8242,7 +8242,7 @@ static void display_channel_pixmap_sync(DisplayChannel *display_channel)
 
     spice_marshall_msg_wait_for_channels(display_channel->base.send_data.marshaller, &wait);
 
-    display_begin_send_massage(display_channel, NULL);
+    display_begin_send_message(display_channel, NULL);
 }
 
 static void display_channel_reset_cache(DisplayChannel *display_channel)
@@ -8254,7 +8254,7 @@ static void display_channel_reset_cache(DisplayChannel *display_channel)
 
     spice_marshall_msg_display_inval_all_pixmaps(display_channel->base.send_data.marshaller,
                                                  &wait);
-    display_begin_send_massage(display_channel, NULL);
+    display_begin_send_message(display_channel, NULL);
 }
 
 static void red_send_image(DisplayChannel *display_channel, ImageItem *item)
@@ -8388,7 +8388,7 @@ static void red_send_image(DisplayChannel *display_channel, ImageItem *item)
         spice_marshaller_add_ref(data_out, item->data, bitmap.y * bitmap.stride);
         region_remove(surface_lossy_region, &copy.base.box);
     }
-    display_begin_send_massage(display_channel, &item->link);
+    display_begin_send_message(display_channel, &item->link);
 
     spice_chunks_destroy(chunks);
 }
@@ -8423,7 +8423,7 @@ static void red_display_send_upgrade(DisplayChannel *display_channel, UpgradeIte
 
     fill_bits(display_channel, src_bitmap_out, copy.data.src_bitmap, item->drawable, FALSE);
 
-    display_begin_send_massage(display_channel, &item->base);
+    display_begin_send_message(display_channel, &item->base);
 }
 
 static void red_display_send_stream_start(DisplayChannel *display_channel, StreamAgent *agent)
@@ -8461,9 +8461,9 @@ static void red_display_send_stream_start(DisplayChannel *display_channel, Strea
 
 
     if (stream->current) {
-        display_begin_send_massage(display_channel, &stream->current->pipe_item);
+        display_begin_send_message(display_channel, &stream->current->pipe_item);
     } else {
-        display_begin_send_massage(display_channel, NULL);
+        display_begin_send_message(display_channel, NULL);
     }
 }
 
@@ -8486,7 +8486,7 @@ static void red_display_send_stream_clip(DisplayChannel *display_channel,
 
     spice_marshall_msg_display_stream_clip(channel->send_data.marshaller, &stream_clip);
 
-    display_begin_send_massage(display_channel, item);
+    display_begin_send_message(display_channel, item);
 }
 
 static void red_display_send_stream_end(DisplayChannel *display_channel, StreamAgent* agent)
@@ -8499,7 +8499,7 @@ static void red_display_send_stream_end(DisplayChannel *display_channel, StreamA
 
     spice_marshall_msg_display_stream_destroy(channel->send_data.marshaller, &destroy);
 
-    display_begin_send_massage(display_channel, NULL);
+    display_begin_send_message(display_channel, NULL);
 }
 
 static void red_cursor_send_inval(CursorChannel *channel, CacheItem *cach_item)
@@ -8528,7 +8528,7 @@ static void red_send_cursor_init(CursorChannel *channel)
     spice_marshall_msg_cursor_init(channel->base.send_data.marshaller, &msg);
     add_buf_from_info(&channel->base, channel->base.send_data.marshaller, &info);
 
-    red_begin_send_massage(&channel->base, worker->cursor);
+    red_begin_send_message(&channel->base, worker->cursor);
 }
 
 static void red_send_local_cursor(CursorChannel *cursor_channel, LocalCursor *cursor)
@@ -8548,7 +8548,7 @@ static void red_send_local_cursor(CursorChannel *cursor_channel, LocalCursor *cu
     spice_marshall_msg_cursor_set(channel->send_data.marshaller, &cursor_set);
     add_buf_from_info(channel, channel->send_data.marshaller, &info);
 
-    red_begin_send_massage(channel, cursor);
+    red_begin_send_message(channel, cursor);
 
     red_release_cursor(channel->worker, (CursorItem *)cursor);
 }
@@ -8561,7 +8561,7 @@ static void cursor_channel_send_migrate(CursorChannel *cursor_channel)
     migrate.flags = 0;
 
     spice_marshall_msg_migrate(cursor_channel->base.send_data.marshaller, &migrate);
-    red_begin_send_massage((RedChannel*)cursor_channel, NULL);
+    red_begin_send_message((RedChannel*)cursor_channel, NULL);
 }
 
 static void red_send_cursor(CursorChannel *cursor_channel, CursorItem *cursor)
@@ -8616,7 +8616,7 @@ static void red_send_cursor(CursorChannel *cursor_channel, CursorItem *cursor)
         red_error("bad cursor command %d", cmd->type);
     }
 
-    red_begin_send_massage(channel, cursor);
+    red_begin_send_message(channel, cursor);
 
     red_release_cursor(channel->worker, cursor);
 }
@@ -8633,7 +8633,7 @@ static void red_send_surface_create(DisplayChannel *display, SpiceMsgSurfaceCrea
 
     spice_marshall_msg_display_surface_create(channel->send_data.marshaller, surface_create);
 
-    red_begin_send_massage(channel, NULL);
+    red_begin_send_message(channel, NULL);
 }
 
 static void red_send_surface_destroy(DisplayChannel *display, uint32_t surface_id)
@@ -8651,7 +8651,7 @@ static void red_send_surface_destroy(DisplayChannel *display, uint32_t surface_i
 
     spice_marshall_msg_display_surface_destroy(channel->send_data.marshaller, &surface_destroy);
 
-    red_begin_send_massage(channel, NULL);
+    red_begin_send_message(channel, NULL);
 }
 
 static inline PipeItem *red_pipe_get(RedChannel *channel)
@@ -9135,7 +9135,7 @@ static inline void red_create_surface(RedWorker *worker, uint32_t surface_id, ui
     PANIC("unable to create drawing canvas");
 }
 
-static void red_wait_outgoiong_item(RedChannel *channel);
+static void red_wait_outgoing_item(RedChannel *channel);
 
 static inline void flush_display_commands(RedWorker *worker)
 {
@@ -10033,7 +10033,7 @@ static void red_cursor_flush(RedWorker *worker)
     red_release_cursor(worker, &local->base);
 }
 
-static void red_wait_outgoiong_item(RedChannel *channel)
+static void red_wait_outgoing_item(RedChannel *channel)
 {
     uint64_t end_time;
     int blocked;
@@ -10129,7 +10129,7 @@ static inline void destroy_surface_wait(RedWorker *worker, int surface_id)
     red_current_clear(worker, surface_id);
     red_clear_surface_glz_drawables(worker, surface_id);
     red_clear_surface_drawables_from_pipe(worker, surface_id);
-    red_wait_outgoiong_item((RedChannel *)worker->display_channel);
+    red_wait_outgoing_item((RedChannel *)worker->display_channel);
     if (worker->display_channel) {
         ASSERT(!worker->display_channel->base.send_data.item);
     }
@@ -10174,7 +10174,7 @@ static inline void handle_dev_destroy_surfaces(RedWorker *worker)
     }
     ASSERT(ring_is_empty(&worker->streams));
 
-    red_wait_outgoiong_item((RedChannel *)worker->cursor_channel);
+    red_wait_outgoing_item((RedChannel *)worker->cursor_channel);
     if (worker->cursor_channel) {
         red_pipe_add_type(&worker->cursor_channel->base, PIPE_ITEM_TYPE_INVAL_CURSOR_CACHE);
         if (!worker->cursor_channel->base.migrate) {
@@ -10253,7 +10253,7 @@ static inline void handle_dev_destroy_primary_surface(RedWorker *worker)
         worker->cursor = NULL;
     }
 
-    red_wait_outgoiong_item((RedChannel *)worker->cursor_channel);
+    red_wait_outgoing_item((RedChannel *)worker->cursor_channel);
     if (worker->cursor_channel) {
         red_pipe_add_type(&worker->cursor_channel->base, PIPE_ITEM_TYPE_INVAL_CURSOR_CACHE);
         if (!worker->cursor_channel->base.migrate) {
@@ -10311,7 +10311,7 @@ static void handle_dev_input(EventListener *listener, uint32_t events)
             worker->cursor = NULL;
         }
 
-        red_wait_outgoiong_item((RedChannel *)worker->cursor_channel);
+        red_wait_outgoing_item((RedChannel *)worker->cursor_channel);
         if (worker->cursor_channel) {
             red_pipe_add_type(&worker->cursor_channel->base, PIPE_ITEM_TYPE_INVAL_CURSOR_CACHE);
             if (!worker->cursor_channel->base.migrate) {
@@ -10371,8 +10371,8 @@ static void handle_dev_input(EventListener *listener, uint32_t events)
             }
         }
         red_cursor_flush(worker);
-        red_wait_outgoiong_item((RedChannel *)worker->display_channel);
-        red_wait_outgoiong_item((RedChannel *)worker->cursor_channel);
+        red_wait_outgoing_item((RedChannel *)worker->display_channel);
+        red_wait_outgoing_item((RedChannel *)worker->cursor_channel);
         message = RED_WORKER_MESSAGE_READY;
         write_message(worker->channel, &message);
         break;
diff --git a/server/reds.c b/server/reds.c
index 8c16896..1a227ae 100644
--- a/server/reds.c
+++ b/server/reds.c
@@ -294,7 +294,7 @@ typedef struct RedsState {
 } RedsState;
 
 uint64_t bitrate_per_sec = ~0;
-static uint64_t letancy = 0;
+static uint64_t latency = 0;
 
 static RedsState *reds = NULL;
 
@@ -750,7 +750,7 @@ static void reds_disconnect()
     reds->in_handler.end_pos = 0;
 
     bitrate_per_sec = ~0;
-    letancy = 0;
+    latency = 0;
 
     reds_mig_cleanup();
     reds->disconnecting = FALSE;
@@ -1721,20 +1721,20 @@ static void reds_main_handle_message(void *opaque, size_t size, uint32_t type, v
             case NET_TEST_STAGE_LATENCY:
                 reds->net_test_id++;
                 reds->net_test_stage = NET_TEST_STAGE_RATE;
-                letancy = roundtrip;
+                latency = roundtrip;
                 break;
             case NET_TEST_STAGE_RATE:
                 reds->net_test_id = 0;
-                if (roundtrip <= letancy) {
+                if (roundtrip <= latency) {
                     // probably high load on client or server result with incorrect values
-                    letancy = 0;
-                    red_printf("net test: invalid values, letancy %lu roundtrip %lu. assuming high"
-                               "bandwidth", letancy, roundtrip);
+                    latency = 0;
+                    red_printf("net test: invalid values, latency %lu roundtrip %lu. assuming high"
+                               "bandwidth", latency, roundtrip);
                     break;
                 }
-                bitrate_per_sec = (uint64_t)(NET_TEST_BYTES * 8) * 1000000 / (roundtrip - letancy);
-                red_printf("net test: letancy %f ms, bitrate %lu bps (%f Mbps)%s",
-                           (double)letancy / 1000,
+                bitrate_per_sec = (uint64_t)(NET_TEST_BYTES * 8) * 1000000 / (roundtrip - latency);
+                red_printf("net test: latency %f ms, bitrate %lu bps (%f Mbps)%s",
+                           (double)latency / 1000,
                            bitrate_per_sec,
                            (double)bitrate_per_sec / 1024 / 1024,
                            IS_LOW_BANDWIDTH() ? " LOW BANDWIDTH" : "");
diff --git a/spice.proto b/spice.proto
index f6aa34e..abb85cc 100644
--- a/spice.proto
+++ b/spice.proto
@@ -753,7 +753,7 @@ channel DisplayChannel : BaseChannel {
 
     message {
 	DisplayBase base;
-	struct AlphaBlnd {
+	struct AlphaBlend {
 	    alpha_flags alpha_flags;
 	    uint8 alpha;
 	    Image *src_bitmap;
diff --git a/spice1.proto b/spice1.proto
index d1efb55..b4012bd 100644
--- a/spice1.proto
+++ b/spice1.proto
@@ -710,7 +710,7 @@ channel DisplayChannel : BaseChannel {
 
     message {
 	DisplayBase base;
-	struct AlphaBlnd {
+	struct AlphaBlend {
 	    int8 alpha_flags @virtual(0);
 	    uint8 alpha;
 	    Image *src_bitmap;


More information about the Spice-commits mailing list
diff --git a/server/red_channel.h b/server/red_channel.h
index c53bf6d..509da77 100644
--- a/server/red_channel.h
+++ b/server/red_channel.h
@@ -169,8 +169,8 @@ void red_channel_add_buf(RedChannel *channel, void *data, uint32_t size);
 
 uint64_t red_channel_get_message_serial(RedChannel *channel);
 
-/* when sending a msg. should first call red_channel_begin_send_massage */
-void red_channel_begin_send_massage(RedChannel *channel);
+/* when sending a msg. should first call red_channel_begin_send_message */
+void red_channel_begin_send_message(RedChannel *channel);
 
 void red_channel_pipe_item_init(RedChannel *channel, PipeItem *item, int type);
 void red_channel_pipe_add(RedChannel *channel, PipeItem *item);